# My Grid System

A highly configurable CSS grid system. Built using PostCSS.

# Table of Contents
* [Features](#features)
* [Quick Start](#quick-start)
* [Examples](#examples)
* [NPM Package](#npm-package)
* [Advanced Usage](#advanced-usage)

# Features

* Easily configure grid width, number of columns and gutter size
* Seamlessly switch between **float** or **flexbox** layouts without the need to
  change any markup
* Add custom media queries and breakpoints easily

# Quick Start

The quickest way to get up and running is to include the following stylesheet in
 your page.

    https://rawgit.com/donnyburnside/my-grid-system/master/dist/grid.min.css

It's highly recommended that you use the NPM package for anything other than
testing as it offers all of the customisation benefits.

# Examples

See `example/index.html` for examples of using the grid.

# NPM Package

* Create a new NPM project by running `npm init` in a new directory (or navigate
  to an existing one)
* Run `npm install my-grid-system`
* Include the pre-compiled stylesheet from `node_modules/my-grid-system/dist/`
  in your project

# Advanced Usage

PostCSS users can include the source files
(found in `node_modules/my-grid-system/src/`) in their builds to compile the
grid system locally.

The code below is an example of integrating the grid (with custom settings) into an existing stylesheet.

    @import "../../node_modules/my-grid-system/src/settings";
    @import "../../node_modules/my-grid-system/src/helpers";

    $grid-type: float;
    $grid-width: 1280px;
    $grid-gutter: 10px;
    $grid-breakpoints: (568, 768, 1024, 1280);

    .container {
      @mixin container;
    }

    .row {
      @mixin row;
    }

    .column {
      @mixin column;
    }

All the necessary CSS is generated during the build process so you can freely
add or remove breakpoints or change the grid type without having to change any
grid markup.

See the included `gulpfile.js` for a bare minimum Gulp/PostCSS build setup.

# Contributors

* [Donny Burnside](http://donnyburnside.com)
